@@ -1,11 +1,10 @@
-import objc
-from objc import super
-import Cocoa
-import Quartz
-
-
-from math import pi as PI
 import random
+from math import pi as PI
+
+import Cocoa
+import objc
+import Quartz
+from objc import super
 
 
 class DemoView(Cocoa.NSView):
@@ -109,7 +108,13 @@ def circles(context, rect):
             v = h
 
         Quartz.CGContextAddArc(
-            context, Quartz.CGRectGetMidX(r), Quartz.CGRectGetMidY(r), v, 0, 2 * PI, False
+            context,
+            Quartz.CGRectGetMidX(r),
+            Quartz.CGRectGetMidY(r),
+            v,
+            0,
+            2 * PI,
+            False,
         )
         Quartz.CGContextClosePath(context)
 
@@ -138,7 +143,9 @@ def bezierPaths(context, rect):
             else:
                 c1 = randomPointInRect(rect)
                 c2 = randomPointInRect(rect)
-                Quartz.CGContextAddCurveToPoint(context, c1.x, c1.y, c2.x, c2.y, p.x, p.y)
+                Quartz.CGContextAddCurveToPoint(
+                    context, c1.x, c1.y, c2.x, c2.y, p.x, p.y
+                )
 
         if k % 2 == 0:
             setRandomFillColor(context)
