@@ -1,21 +1,18 @@
-import Quartz
-import Cocoa
-
-import Utilities
-import UIHandling
-import Images
-import ImageMasking
 import BitmapContext
-import EPSPrinting
-import CoordinateSystem
-import PathDrawing
+import Cocoa
 import ColorAndGState
-import QuartzTextDrawing
-import PatternDrawing
-import ShadowsAndTransparencyLayers
-import Shadings
+import CoordinateSystem
 import DrawingBasics
-
+import EPSPrinting
+import ImageMasking
+import Images
+import PathDrawing
+import PatternDrawing
+import QuartzTextDrawing
+import Shadings
+import ShadowsAndTransparencyLayers
+import UIHandling
+import Utilities
 
 # Defines
 kCatPDF = "Kitty.pdf"
@@ -93,7 +90,9 @@ def doRawImageFileWithURL(context):
     url = GetURL(kRawColorImage)
 
     if url is not None:
-        Images.drawImageFromURL(context, url, RAW_IMAGE_WIDTH, RAW_IMAGE_HEIGHT, 8, True)
+        Images.drawImageFromURL(
+            context, url, RAW_IMAGE_WIDTH, RAW_IMAGE_HEIGHT, 8, True
+        )
         # 8 bits per component, isColor = True
 
 
@@ -279,7 +278,9 @@ def DispatchDrawing(context, drawingType):
         ColorAndGState.drawWithGlobalAlpha(context)
 
     elif drawingType == UIHandling.kHICommandDrawWithBlendMode:
-        callPDFDrawProc(context, ColorAndGState.drawWithColorBlendMode, kPDFForBlendMode)
+        callPDFDrawProc(
+            context, ColorAndGState.drawWithColorBlendMode, kPDFForBlendMode
+        )
 
     elif drawingType == UIHandling.kHICommandDrawWithColorRefs:
         ColorAndGState.drawWithColorRefs(context)
@@ -396,7 +397,9 @@ def DispatchDrawing(context, drawingType):
         ShadowsAndTransparencyLayers.drawFillAndStrokeWithShadow(context)
 
     elif drawingType == UIHandling.kHICommandPDFDocumentShadow:
-        callPDFDrawProc(context, ShadowsAndTransparencyLayers.shadowPDFDocument, kCatPDF)
+        callPDFDrawProc(
+            context, ShadowsAndTransparencyLayers.shadowPDFDocument, kCatPDF
+        )
 
     elif drawingType == UIHandling.kHICommandSimpleAxialShading:
         Shadings.doSimpleAxialShading(context)
